# Instructions for Downloading ECCO Datasets hosted on PODAAC

## Using Python 3 & Jupyter Notebooks

[Python 3 Jupyter Notebook (ipynb)](Tutorial_Python3_Jupyter_Notebook_Downloading_ECCO_Datasets_from_PODAAC.ipynb)

[Python 3 Jupyter Notebook (pdf)](Tutorial_Python3_Jupyter_Notebook_Downloading_ECCO_Datasets_from_PODAAC.pdf)

## Using Command Line *_wget_* and NASA Earthdata

[_wget_ command line instructions (markdown)](Tutorial_wget_Command_Line_HTTPS_Downloading_ECCO_Datasets_from_PODAAC.md)

[_wget_ command line instructions (pdf)](Tutorial_wget_Command_Line_HTTPS_Downloading_ECCO_Datasets_from_PODAAC.md)
